==> civicrm_5.11.0%2Bdfsg.orig.tar.xz: civicrm/release-notes/5.10.4.md <==
# CiviCRM 5.10.4

Released February 22, 2019

- **[Synopsis](#synopsis)**
- **[Bugs resolved](#bugs)**
- **[Credits](#credits)**
- **[Feedback](#feedback)**

## <a name="synopsis"></a>Synopsis

| *Does this version...?*                                         |         |
|:--------------------------------------------------------------- |:-------:|
| Fix security vulnerabilities?                                   |   no    |
| Change the database schema?                                     |   no    |
| Alter the API?                                                  |   no    |
| Require attention to configuration options?                     |   no    |
| Fix problems installing or upgrading to a previous version?     |   no    |
| Introduce features?                                             |   no    |
| **Fix bugs?**                                                   | **yes** |

## <a name="bugs"></a>Bugs resolved

- **([dev/core#747](https://lab.civicrm.org/dev/core/issues/747)) Contact images
  can no longer be viewed or re-uploaded
  ([13679](https://github.com/civicrm/civicrm-core/pull/13679))**

  Following the security release, loading of images on the contact summary
  screen broke due to the removal of handling of the filename url parameter

- **([dev/report#10](https://lab.civicrm.org/dev/report/issues/10)) No
  pagination on Contribution Detail report
  ([13677](https://github.com/civicrm/civicrm-core/pull/13677))**

  Fixed a recent regression where the pagination on the Contribution Detail
  report broke.

- **([dev/core#746](https://lab.civicrm.org/dev/core/issues/746)) Search Builder
  searches using > 1 smart group where operator is equals is broken from 5.10.0
  ([13667](https://github.com/civicrm/civicrm-core/pull/13667))**

  This fixes a recent regression whereby if you had more than one `WHERE`
  clause involving groups, and the groups were smart groups, it wouldn't return
  the correct results.


## <a name="credits"></a>Credits

This release was developed by the following authors and reviewers:

Wikimedia Foundation - Eileen McNaughton; Fuzion - Jitendra Purohit;
Semper IT - Karin Gerritsen; CiviCRM - Tim Otten;
Australian Greens - Seamus Lee; Blackfly Solutions - Alan Dixon;
Megaphone Technology Consulting - Jon Goldberg;

## <a name="feedback"></a>Feedback

These release notes are edited by Tim Otten and Andrew Hunt. If you'd like to
provide feedback on them, please login to https://chat.civicrm.org/civicrm and
contact `@agh1`.

==> civicrm_5.18.1%2Bdfsg.orig.tar.xz: civicrm/release-notes/5.13.1.md <==
# CiviCRM 5.13.1

Released May 2, 2019

- **[Synopsis](#synopsis)**
- **[Bugs resolved](#bugs)**
- **[Credits](#credits)**
- **[Feedback](#feedback)**

## <a name="synopsis"></a>Synopsis

| *Does this version...?*                                         |         |
|:--------------------------------------------------------------- |:-------:|
| Fix security vulnerabilities?                                   |   no    |
| Change the database schema?                                     |   no    |
| Alter the API?                                                  |   no    |
| Require attention to configuration options?                     |   no    |
| Fix problems installing or upgrading to a previous version?     |   no    |
| Introduce features?                                             |   no    |
| **Fix bugs?**                                                   | **yes** |

## <a name="bugs"></a>Bugs resolved

- **Fix upgrade failure on multilingual sites ([dev/core#931](https://lab.civicrm.org/dev/core/issues/931): [14187](https://github.com/civicrm/civicrm-core/pull/14187))**

- **Fix regression in REST endpoint on WordPress ([dev/wordpress#26](https://lab.civicrm.org/dev/wordpress/issues/26): [14186](https://github.com/civicrm/civicrm-core/pull/14186))**

## <a name="credits"></a>Credits

This release was developed by the following authors and reviewers:

Australian Greens - Seamus Lee; Megaphone Technology Consulting - Jon Goldberg;
Tadpole Collective - Kevin Cristiano;

## <a name="feedback"></a>Feedback

These release notes are edited by Tim Otten and Andrew Hunt.  If you'd like to
provide feedback on them, please login to https://chat.civicrm.org/civicrm and
contact `@agh1`.
